@@ -193,6 +193,10 @@ static void ste_eppsd_up_cb(gboolean ok, GAtResult *result, gpointer user_data)
 	for (i = 0; i < g_at_result_num_response_lines(result); i++) {
 		g_at_result_iter_next(&iter, NULL);
 		res_string = g_at_result_iter_raw_line(&iter);
+
+		if (res_string == NULL)
+			goto error;
+
 		length = strlen(res_string);
 
 		if (!g_markup_parse_context_parse(context, res_string,
@@ -412,6 +416,7 @@ out:
 }
 
 static const struct ofono_gprs_context_driver driver = {
+	.flags			= OFONO_ATOM_DRIVER_FLAG_REGISTER_ON_PROBE,
 	.probe			= ste_gprs_context_probe,
 	.remove			= ste_gprs_context_remove,
 	.activate_primary	= ste_gprs_activate_primary,
