@@ -57,6 +57,7 @@
 #define GOBI_UIM	(1 << 5)
 #define GOBI_VOICE	(1 << 6)
 #define GOBI_WDA	(1 << 7)
+#define GOBI_LTE	(1 << 8)
 
 #define MAX_CONTEXTS 4
 #define DEFAULT_MTU 1400
@@ -108,6 +109,7 @@ struct gobi_data {
 	uint32_t set_powered_id;
 	uint32_t set_mtu_id;
 	enum wda_data_format data_format;
+	uint8_t off_opmode;
 	bool no_pass_through : 1;
 };
 
@@ -216,12 +218,14 @@ static int gobi_probe(struct ofono_modem *modem)
 	struct gobi_data *data;
 	const char *if_driver;
 	const char *ifname;
+	const char *opmode;
 	uint8_t interface_number;
 	int ifindex;
 	const char *bus;
 	struct stat st;
 	_auto_(l_free) char *pass_through = NULL;
 	bool no_pass_through = false;
+	uint8_t off_opmode = QMI_DMS_OPER_MODE_LOW_POWER;
 
 	DBG("%p", modem);
 
@@ -230,6 +234,7 @@ static int gobi_probe(struct ofono_modem *modem)
 	ifname = ofono_modem_get_string(modem, "NetworkInterface");
 	ifindex = ofono_modem_get_integer(modem, "NetworkInterfaceIndex");
 	bus = ofono_modem_get_string(modem, "Bus");
+	opmode = ofono_modem_get_string(modem, "OfflineOperatingMode");
 
 	DBG("net: %s[%s](%d) %s", ifname, if_driver, ifindex, bus);
 
@@ -254,6 +259,15 @@ static int gobi_probe(struct ofono_modem *modem)
 			return -errno;
 	}
 
+	if (opmode) {
+		DBG("offline power mode: %s", opmode);
+
+		if (!strcmp(opmode, "PersistentLowPower"))
+			off_opmode = QMI_DMS_OPER_MODE_PERSIST_LOW_POWER;
+		else if (strcmp(opmode, "LowPower"))
+			return -ENOTSUP;
+	}
+
 	data = l_new(struct gobi_data, 1);
 	data->main_net_ifindex = ifindex;
 	l_strlcpy(data->main_net_name, ifname, sizeof(data->main_net_name));
@@ -261,9 +275,9 @@ static int gobi_probe(struct ofono_modem *modem)
 	data->no_pass_through = no_pass_through;
 	/* See drivers/net/ethernet/qualcomm/rmnet/rmnet_private.h */
 	data->max_aggregation_size = 16384;
+	data->off_opmode = off_opmode;
 
 	ofono_modem_set_data(modem, data);
-	ofono_modem_set_capabilities(modem, OFONO_MODEM_CAPABILITY_LTE);
 
 	return 0;
 }
@@ -442,7 +456,7 @@ static void get_oper_mode_cb(struct qmi_result *result, void *user_data)
 	switch (data->oper_mode) {
 	case QMI_DMS_OPER_MODE_ONLINE:
 		param = qmi_param_new_uint8(QMI_DMS_PARAM_OPER_MODE,
-					QMI_DMS_OPER_MODE_LOW_POWER);
+						data->off_opmode);
 		if (!param) {
 			shutdown_device(modem);
 			return;
@@ -480,8 +494,17 @@ static void get_caps_cb(struct qmi_result *result, void *user_data)
         DBG("service capabilities %d", caps->data_capa);
         DBG("sim supported %d", caps->sim_supported);
 
-        for (i = 0; i < caps->radio_if_count; i++)
-                DBG("radio = %d", caps->radio_if[i]);
+	for (i = 0; i < caps->radio_if_count; i++) {
+		uint8_t iface = caps->radio_if[i];
+
+		DBG("radio = %d", iface);
+
+		if (iface == QMI_DMS_RADIO_IF_LTE)
+			data->features |= GOBI_LTE;
+	}
+
+	if (data->features & GOBI_LTE)
+		ofono_modem_set_capabilities(modem, OFONO_MODEM_CAPABILITY_LTE);
 
 	if (qmi_service_send(data->dms, QMI_DMS_GET_OPER_MODE, NULL,
 					get_oper_mode_cb, modem, NULL) > 0)
@@ -527,7 +550,7 @@ error:
 	shutdown_device(modem);
 }
 
-static uint32_t start_service_requests(struct ofono_modem *modem)
+static bool start_service_requests(struct ofono_modem *modem)
 {
 	struct gobi_data *data = ofono_modem_get_data(modem);
 	unsigned int i;
@@ -570,7 +593,7 @@ static void rmnet_get_interfaces_cb(int error, unsigned int n_interfaces,
 				sizeof(struct rmnet_ifinfo) * n_interfaces);
 	data->n_premux = n_interfaces;
 
-	if (start_service_requests(modem) > 0)
+	if (start_service_requests(modem))
 		return;
 error:
 	shutdown_device(modem);
@@ -618,7 +641,7 @@ static void enable_set_mtu_cb(int error, uint16_t type,
 		goto error;
 	}
 
-	if (start_service_requests(modem) > 0)
+	if (start_service_requests(modem))
 		return;
 error:
 	shutdown_device(modem);
@@ -665,10 +688,21 @@ static void set_data_format_cb(struct qmi_result *result, void *user_data)
 	DBG("");
 
 	if (!qmi_result_set_error(result, NULL)) {
+		struct qmi_wda_data_format actual;
+
 		if (!compare_data_format(data, result))
 			goto done;
 
 		ofono_error("Setting Data Format had no effect");
+
+		if (!qmi_wda_parse_data_format(result, &actual) &&
+				data->data_format == WDA_DATA_FORMAT_802_3 &&
+				actual.ll_protocol ==
+				QMI_WDA_DATA_LINK_PROTOCOL_RAW_IP) {
+			ofono_warn("Modem seems to only work in raw-ip mode");
+			data->data_format = WDA_DATA_FORMAT_RAW_IP;
+			goto done;
+		}
 	}
 
 	if (data->data_format == WDA_DATA_FORMAT_802_3)
@@ -717,7 +751,7 @@ static void create_wda_cb(struct qmi_service *service, void *user_data)
 		DBG("Failed to request WDA service, assume 802.3");
 
 		if (qmi_qmux_device_create_client(data->device, QMI_SERVICE_DMS,
-					request_service_cb, modem, NULL) > 0)
+					request_service_cb, modem, NULL))
 			return;
 
 		goto error;
@@ -792,11 +826,16 @@ static void discover_cb(void *user_data)
 		add_service_request(data, &data->wms, QMI_SERVICE_WMS);
 	if (data->features & GOBI_VOICE)
 		add_service_request(data, &data->voice, QMI_SERVICE_VOICE);
+	if (data->features & GOBI_PDS)
+		add_service_request(data, &data->pds, QMI_SERVICE_PDS);
 	if (data->features & GOBI_UIM)
 		add_service_request(data, &data->uim, QMI_SERVICE_UIM);
 
-	if (qmi_qmux_device_create_client(data->device, QMI_SERVICE_WDA,
-						create_wda_cb, modem, NULL))
+	if (data->features & GOBI_WDA) {
+		if (qmi_qmux_device_create_client(data->device,
+				QMI_SERVICE_WDA, create_wda_cb, modem, NULL))
+			return;
+	} else if (start_service_requests(modem))
 		return;
 
 error:
@@ -921,8 +960,7 @@ static int gobi_disable(struct ofono_modem *modem)
 	if (ofono_modem_get_boolean(modem, "AlwaysOnline"))
 		goto out;
 
-	param = qmi_param_new_uint8(QMI_DMS_PARAM_OPER_MODE,
-					QMI_DMS_OPER_MODE_LOW_POWER);
+	param = qmi_param_new_uint8(QMI_DMS_PARAM_OPER_MODE, data->off_opmode);
 	if (!param)
 		return -ENOMEM;
 
@@ -1139,7 +1177,7 @@ static void gobi_post_sim(struct ofono_modem *modem)
 
 	DBG("%p", modem);
 
-	if (data->features & GOBI_WDS)
+	if (data->features & GOBI_WDS && data->features & GOBI_LTE)
 		ofono_lte_create(modem, 0, "qmimodem",
 					qmi_service_clone(data->wds));
 
